@@ -6,16 +6,17 @@ use vars qw( $session $DefaultClass @EXPORT  @ISA $defaultconfig);
 @CGI::CMS::Session::EXPORT = qw(loadSession saveSession $session);
 use CGI::CMS::Config;
 @CGI::CMS::Session::ISA     = qw(Exporter CGI::CMS::Config);
-$CGI::CMS::Session::VERSION = '0.29';
+$CGI::CMS::Session::VERSION = '0.3';
 $DefaultClass               = 'CGI::CMS::Session' unless defined $CGI::CMS::Session::DefaultClass;
 $defaultconfig              = '%CONFIG%';
 
 =head1 NAME
 
-CGI::CMS::Session
+CGI::CMS::Session - store the sessions for CGI::CMS
 
 =head1 SYNOPSIS
 
+see l<CGI::CMS>
 
 =head1 DESCRIPTION
 
