@@ -11,12 +11,12 @@ our $server;
 @Template::Quick::Main::EXPORT_OK   = qw(all initMain Header Footer);
 %Template::Quick::Main::EXPORT_TAGS = ('all' => [qw(initMain Header Footer)]);
 @Template::Quick::Main::ISA         = qw( Exporter Template::Quick);
-$Template::Quick::Main::VERSION     = '0.29';
+$Template::Quick::Main::VERSION     = '0.3';
 $DefaultClass                       = 'Template::Quick::Main' unless defined $Template::Quick::Main::DefaultClass;
 
 =head1 NAME
 
-Template::Quick::Main.pm
+Template::Quick::Main - used by CGI::CMS::GUI
 
 =head1 SYNOPSIS
 
